starcluster.tests.templates.config

Package starcluster :: Package tests :: Package templates :: Module config |
[hide private]
[frames] | no frames]

# Module config

source code

Variables | [hide private]
| default_config = ``{``'``aws_access_key_id``'``:` `'``asd0asd9f0asd0fas0d9f0``...``
| config_test_template = ``'``\n[global]\nDEFAULT=%(default)s\nENABL``...``
| __package__ = `None` hash(x)

Variables Details | [hide private]

  ### default_config Value:
      {'aws_access_key_id': 'asd0asd9f0asd0fas0d9f0',
       'aws_secret_access_key': 'asdf0a9sdf09203fj0asdf',
       'aws_user_id': 9009230923,
       'c1_keyname': 'k1',
       'c1_master_id': 'ami-8f9e71e6',
       'c1_master_type': 'm1.small',
       'c1_node_id': 'ami-8f9e71e6',
       'c1_node_type': 'm1.small',
      ...

  ### config_test_template Value:
      '''
      [global]
      DEFAULT=%(default)s
      ENABLE_EXPERIMENTAL=%(enable_experimental)s

      [aws info]
      AWS_ACCESS_KEY_ID = %(aws_access_key_id)s
      AWS_SECRET_ACCESS_KEY = %(aws_secret_access_key)s
      ...